document.addEventListener('DOMContentLoaded', function () {
    const paymentOptionSelector = 'input[name="payment-option"]';
    let originalTotal = 0;
    let currencySymbol = '';
    let symbolIsAfter = false;
    const textoCargoAdicional = 'Cargo adicional por servicio';
    const totalElement = document.querySelector('.cart-summary-totals .value');

    document.querySelectorAll(paymentOptionSelector).forEach(function (element) {
        element.addEventListener('change', function () {
            extractCurrencyDetails(totalElement.textContent);
            originalTotal = getSubtotalSum();

            if (this.checked && this.dataset.moduleName === 'flowpaymentflow') {
                const additionalCharge = getAdditionalCharge('flowpaymentflow');
                updateTotalWithExtraFee(additionalCharge);
            } else {
                resetTotal();
            }
        });
    });

    function extractCurrencyDetails(text) {
        const matches = text.match(/[\d.,]+/);
        if (matches) {
            const index = text.indexOf(matches[0]);
            currencySymbol = (index > 0) ? text.substring(0, index).trim() : text.substring(matches[0].length + index).trim();
            symbolIsAfter = index <= 0;
        }
    }

    function extractNumericalValue(text) {
        return Number(text.replace(/\./g, '').replace(/[^0-9]/g, ''));
    }

    function getAdditionalCharge(moduleName) {
        const paymentOptionInput = document.querySelector(`input[data-module-name="${moduleName}"]`);
        const paymentOptionContainer = paymentOptionInput.closest('.payment-option');

        if (paymentOptionContainer) {
            const paymentOptionId = paymentOptionContainer.getAttribute('id').replace('-container', '-additional-information');
            const additionalInfoContainer = document.getElementById(paymentOptionId);

            if (additionalInfoContainer) {
                const chargeText = additionalInfoContainer.textContent.match(/equivalente a [^\d]*(\d+)/);
                if (chargeText && chargeText[1]) {
                    return extractNumericalValue(chargeText[1]);
                }
            }
        }
        return 0;
    }

    function updateTotalWithExtraFee(additionalCharge) {
        const newTotal = originalTotal + additionalCharge;
        totalElement.textContent = formatCurrency(newTotal);

        if(additionalCharge>0){
            let extraFeeElement = document.querySelector('#extra-fee');
            if (!extraFeeElement) {
                extraFeeElement = createExtraFeeElement();
            }
            extraFeeElement.querySelector('.value').textContent = formatCurrency(additionalCharge);
        }
    }

    function resetTotal() {
        const extraFeeElement = document.querySelector('#extra-fee');
        if (extraFeeElement) {
            extraFeeElement.remove();
        }
        totalElement.textContent = formatCurrency(getSubtotalSum());
    }

    function getSubtotalSum() {
        let newTotal = 0;
        document.querySelectorAll('.cart-summary-subtotals .value').forEach(function (element) {
            newTotal += extractNumericalValue(element.textContent);
        });
        return newTotal;
    }

    function formatCurrency(value) {
        const formattedValue = new Intl.NumberFormat('es-CL').format(value);
        return symbolIsAfter ? `${formattedValue} ${currencySymbol}` : `${currencySymbol} ${formattedValue}`;
    }

    function createExtraFeeElement() {
        const container = document.querySelector('.js-cart-summary-subtotals-container');
        const extraFeeElement = document.createElement('div');
        extraFeeElement.className = 'cart-summary-line cart-summary-subtotals';
        extraFeeElement.id = 'extra-fee';
        extraFeeElement.innerHTML = `<span class="label">${textoCargoAdicional}</span><span class="value"></span>`;
        container.appendChild(extraFeeElement);
        return extraFeeElement;
    }
});
